To make the UUID, this module is completely copied from the ecto project under the Apache License 2.0. For more information and more functions, please refer to the following path:
- https://github.com/elixir-ecto/ecto/blob/v3.11.2/lib/ecto/uuid.ex#L1
- https://hexdocs.pm/ecto/Ecto.UUID.html
It should be noted that this file only supports uuid version 4. To use other versions in hex, look for another library